@@ -32,7 +32,7 @@ import ubiquity.tz
 
 
 NAME = 'timezone'
-#after partman for default install, but language for oem install
+# after partman for default install, but language for oem install
 AFTER = ['partman', 'language']
 WEIGHT = 10
 
@@ -66,12 +66,12 @@ class PageGtk(plugin.PluginUI):
         self.online = state
 
     def plugin_translate(self, lang):
-        #c = self.controller
-        #if c.get_string('ubiquity/imported/time-format', lang) == '12-hour':
+        # c = self.controller
+        # if c.get_string('ubiquity/imported/time-format', lang) == '12-hour':
         #    fmt = c.get_string('ubiquity/imported/12-hour', lang)
-        #else:
+        # else:
         #    fmt = c.get_string('ubiquity/imported/24-hour', lang)
-        #self.tzmap.set_time_format(fmt)
+        # self.tzmap.set_time_format(fmt)
         inactive = self.controller.get_string(
             'timezone_city_entry_inactive_label', lang)
         self.city_entry.set_placeholder_text(inactive)
@@ -142,8 +142,9 @@ class PageGtk(plugin.PluginUI):
             # United States (New York) (United States)
             # Might want to match the debconf format.
             name, loc = result
-            model.append([name, '', loc.human_country,
-                          str(loc.latitude), str(loc.longitude)])
+            if loc:
+                model.append([name, '', loc.human_country,
+                              str(loc.latitude), str(loc.longitude)])
 
     def geoname_timeout(self, user_data):
         text, model = user_data
@@ -189,7 +190,7 @@ class PageGtk(plugin.PluginUI):
         self.city_entry.get_completion().set_model(model)
 
     def setup_page(self):
-        # TODO Put a frame around the completion to add contrast (LP: #605908)
+        # TODO Put a frame around the completion to add contrast (LP: # 605908)
         from gi.repository import Gtk, GLib
         from gi.repository import TimezoneMap
         self.tzdb = ubiquity.tz.Database()
@@ -250,7 +251,7 @@ class PageKde(plugin.PluginUI):
     def __init__(self, controller, *args, **kwargs):
         self.controller = controller
         try:
-            from PyQt4 import uic
+            from PyQt5 import uic
             from ubiquity.frontend.kde_components.Timezone import TimezoneMap
 
             self.page = uic.loadUi('/usr/share/ubiquity/qt/stepLocation.ui')
@@ -291,7 +292,7 @@ class PageKde(plugin.PluginUI):
         self.page.timezone_city_combo.clear()
 
         code = str(
-            self.page.timezone_zone_combo.itemData(regionIndex).toPyObject())
+            self.page.timezone_zone_combo.itemData(regionIndex))
         countries = self.controller.dbfilter.get_countries_for_region(code)
         if not countries:  # must have been a country code itself
             countries = [code]
@@ -317,11 +318,11 @@ class PageKde(plugin.PluginUI):
             return
 
         self.page.timezone_city_combo.blockSignals(True)
-        #self.page.timezone_city_combo.currentIndexChanged[int].disconnect(
+        # self.page.timezone_city_combo.currentIndexChanged[int].disconnect(
         #    self.cityChanged)
         default = self.populateCities(regionIndex)
         self.page.timezone_city_combo.blockSignals(False)
-        #self.page.timezone_city_combo.currentIndexChanged[int].connect(
+        # self.page.timezone_city_combo.currentIndexChanged[int].connect(
         #    self.cityChanged)
 
         if default:
@@ -332,7 +333,7 @@ class PageKde(plugin.PluginUI):
     # called when the city combo changes
     def cityChanged(self, cityindex):
         zone = str(
-            self.page.timezone_city_combo.itemData(cityindex).toPyObject())
+            self.page.timezone_city_combo.itemData(cityindex))
         self.tzmap.zoneChanged.disconnect(self.mapZoneChanged)
         self.tzmap.set_timezone(zone)
         self.tzmap.zoneChanged.connect(self.mapZoneChanged)
@@ -343,7 +344,7 @@ class PageKde(plugin.PluginUI):
         self.page.timezone_city_combo.blockSignals(True)
 
         for i in range(self.page.timezone_zone_combo.count()):
-            code = str(self.page.timezone_zone_combo.itemData(i).toPyObject())
+            code = str(self.page.timezone_zone_combo.itemData(i))
             countries = self.controller.dbfilter.get_countries_for_region(code)
             if not countries:  # must have been a country code itself
                 countries = [code]
@@ -353,7 +354,7 @@ class PageKde(plugin.PluginUI):
                 break
 
         for i in range(self.page.timezone_city_combo.count()):
-            code = str(self.page.timezone_city_combo.itemData(i).toPyObject())
+            code = str(self.page.timezone_city_combo.itemData(i))
             if zone == code:
                 self.page.timezone_city_combo.setCurrentIndex(i)
                 self.cityChanged(i)
